@@ -87,9 +87,9 @@ NOMADSRealTimeList <- function(url.type, abbrev = NULL) {
     "Global Forecast System Ensemble National Digital Guidance Database Bias Corrected ",
     "North American Ensemble Forecast System Bias Corrected ",
     "North American Ensemble Forecast System National Digital Guidance Database Bias Corrected ",
-    "NOAA Environmental ing System Global Forecast System Aerosol Component 2D",
-    "NOAA Environmental ing System Global Forecast System Aerosol Component 3D",
-    "NOAA Environmental ing System Global Forecast System Aerosol Optical Depth",
+    "NOAA Environmental Modeling System Global Forecast System Aerosol Component 2D",
+    "NOAA Environmental Modeling System Global Forecast System Aerosol Component 3D",
+    "NOAA Environmental Modeling System Global Forecast System Aerosol Optical Depth",
     "Air Quality Daily Maximum",
     "Air Quality Hourly Surface Ozone",
     "Climate Forecast System Flux Products",
